==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/OBJECTIVEENERGYTARGETID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour OBJECTIVEENERGYTARGETID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="OBJECTIVEENERGYTARGETID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJECTIVEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENERGYTARGETSCOPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENERGYTARGETACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMISSIONSOURCEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OBJECTIVEENERGYTARGETID_Type", propOrder = {
    "objectiveid",
    "energytargetscopeid",
    "energytargetactivityid",
    "emissionsourceid"
})
public class OBJECTIVEENERGYTARGETID_Type {

    @XmlElement(name = "OBJECTIVEID", required = true)
    protected OBJECTIVEID_Type objectiveid;
    @XmlElement(name = "ENERGYTARGETSCOPEID", required = true)
    protected ENERGYTARGETSCOPEID_Type energytargetscopeid;
    @XmlElement(name = "ENERGYTARGETACTIVITYID", required = true)
    protected ENERGYTARGETACTIVITYID_Type energytargetactivityid;
    @XmlElement(name = "EMISSIONSOURCEID", required = true)
    protected EMISSIONSOURCEID_Type emissionsourceid;

    /**
     * Obtient la valeur de la propriété objectiveid.
     * 
     * @return
     *     possible object is
     *     {@link OBJECTIVEID_Type }
     *     
     */
    public OBJECTIVEID_Type getOBJECTIVEID() {
        return objectiveid;
    }

    /**
     * Définit la valeur de la propriété objectiveid.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECTIVEID_Type }
     *     
     */
    public void setOBJECTIVEID(OBJECTIVEID_Type value) {
        this.objectiveid = value;
    }

    /**
     * Obtient la valeur de la propriété energytargetscopeid.
     * 
     * @return
     *     possible object is
     *     {@link ENERGYTARGETSCOPEID_Type }
     *     
     */
    public ENERGYTARGETSCOPEID_Type getENERGYTARGETSCOPEID() {
        return energytargetscopeid;
    }

    /**
     * Définit la valeur de la propriété energytargetscopeid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENERGYTARGETSCOPEID_Type }
     *     
     */
    public void setENERGYTARGETSCOPEID(ENERGYTARGETSCOPEID_Type value) {
        this.energytargetscopeid = value;
    }

    /**
     * Obtient la valeur de la propriété energytargetactivityid.
     * 
     * @return
     *     possible object is
     *     {@link ENERGYTARGETACTIVITYID_Type }
     *     
     */
    public ENERGYTARGETACTIVITYID_Type getENERGYTARGETACTIVITYID() {
        return energytargetactivityid;
    }

    /**
     * Définit la valeur de la propriété energytargetactivityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENERGYTARGETACTIVITYID_Type }
     *     
     */
    public void setENERGYTARGETACTIVITYID(ENERGYTARGETACTIVITYID_Type value) {
        this.energytargetactivityid = value;
    }

    /**
     * Obtient la valeur de la propriété emissionsourceid.
     * 
     * @return
     *     possible object is
     *     {@link EMISSIONSOURCEID_Type }
     *     
     */
    public EMISSIONSOURCEID_Type getEMISSIONSOURCEID() {
        return emissionsourceid;
    }

    /**
     * Définit la valeur de la propriété emissionsourceid.
     * 
     * @param value
     *     allowed object is
     *     {@link EMISSIONSOURCEID_Type }
     *     
     */
    public void setEMISSIONSOURCEID(EMISSIONSOURCEID_Type value) {
        this.emissionsourceid = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/OBJECTIVEENERGYTARGETID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OBJECTIVEENERGYTARGETID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OBJECTIVEENERGYTARGETID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJECTIVEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENERGYTARGETSCOPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENERGYTARGETACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMISSIONSOURCEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OBJECTIVEENERGYTARGETID_Type", propOrder = {
    "objectiveid",
    "energytargetscopeid",
    "energytargetactivityid",
    "emissionsourceid"
})
public class OBJECTIVEENERGYTARGETID_Type {

    @XmlElement(name = "OBJECTIVEID", required = true)
    protected OBJECTIVEID_Type objectiveid;
    @XmlElement(name = "ENERGYTARGETSCOPEID", required = true)
    protected ENERGYTARGETSCOPEID_Type energytargetscopeid;
    @XmlElement(name = "ENERGYTARGETACTIVITYID", required = true)
    protected ENERGYTARGETACTIVITYID_Type energytargetactivityid;
    @XmlElement(name = "EMISSIONSOURCEID", required = true)
    protected EMISSIONSOURCEID_Type emissionsourceid;

    /**
     * Gets the value of the objectiveid property.
     * 
     * @return
     *     possible object is
     *     {@link OBJECTIVEID_Type }
     *     
     */
    public OBJECTIVEID_Type getOBJECTIVEID() {
        return objectiveid;
    }

    /**
     * Sets the value of the objectiveid property.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECTIVEID_Type }
     *     
     */
    public void setOBJECTIVEID(OBJECTIVEID_Type value) {
        this.objectiveid = value;
    }

    /**
     * Gets the value of the energytargetscopeid property.
     * 
     * @return
     *     possible object is
     *     {@link ENERGYTARGETSCOPEID_Type }
     *     
     */
    public ENERGYTARGETSCOPEID_Type getENERGYTARGETSCOPEID() {
        return energytargetscopeid;
    }

    /**
     * Sets the value of the energytargetscopeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENERGYTARGETSCOPEID_Type }
     *     
     */
    public void setENERGYTARGETSCOPEID(ENERGYTARGETSCOPEID_Type value) {
        this.energytargetscopeid = value;
    }

    /**
     * Gets the value of the energytargetactivityid property.
     * 
     * @return
     *     possible object is
     *     {@link ENERGYTARGETACTIVITYID_Type }
     *     
     */
    public ENERGYTARGETACTIVITYID_Type getENERGYTARGETACTIVITYID() {
        return energytargetactivityid;
    }

    /**
     * Sets the value of the energytargetactivityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENERGYTARGETACTIVITYID_Type }
     *     
     */
    public void setENERGYTARGETACTIVITYID(ENERGYTARGETACTIVITYID_Type value) {
        this.energytargetactivityid = value;
    }

    /**
     * Gets the value of the emissionsourceid property.
     * 
     * @return
     *     possible object is
     *     {@link EMISSIONSOURCEID_Type }
     *     
     */
    public EMISSIONSOURCEID_Type getEMISSIONSOURCEID() {
        return emissionsourceid;
    }

    /**
     * Sets the value of the emissionsourceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EMISSIONSOURCEID_Type }
     *     
     */
    public void setEMISSIONSOURCEID(EMISSIONSOURCEID_Type value) {
        this.emissionsourceid = value;
    }

}
